@@ -12,6 +12,8 @@ mod listener;
 pub(crate) use listener::*;
 mod messages;
 pub(crate) use messages::*;
+mod trust_policy;
+pub use trust_policy::*;
 
 #[async_trait]
 impl<P: ProfileTrait + Clone> SecureChannelTrait for P {
@@ -20,10 +22,11 @@ impl<P: ProfileTrait + Clone> SecureChannelTrait for P {
         &mut self,
         ctx: &Context,
         route: Route,
+        trust_policy: impl TrustPolicy,
         vault: &Address,
     ) -> Result<Address> {
         let vault = VaultSync::create_with_worker(ctx, vault)?;
-        Initiator::create(ctx, route, self, vault).await
+        Initiator::create(ctx, route, self, trust_policy, vault).await
     }
 
     /// Create mutually authenticated secure channel listener
@@ -31,10 +34,11 @@ impl<P: ProfileTrait + Clone> SecureChannelTrait for P {
         &mut self,
         ctx: &Context,
         address: Address,
+        trust_policy: impl TrustPolicy,
         vault: &Address,
     ) -> Result<()> {
         let vault = VaultSync::create_with_worker(ctx, vault)?;
-        let listener = ProfileChannelListener::new(self.clone(), vault);
+        let listener = ProfileChannelListener::new(trust_policy, self.clone(), vault);
         ctx.start_worker(address, listener).await
     }
 }
@@ -42,7 +46,7 @@ impl<P: ProfileTrait + Clone> SecureChannelTrait for P {
 #[cfg(test)]
 mod test {
     use super::*;
-    use crate::Profile;
+    use crate::{Profile, ProfileIdentity};
     use ockam_vault_sync_core::Vault;
 
     #[test]
@@ -55,14 +59,23 @@ mod test {
                 let mut alice = Profile::create(&ctx, &vault).await.unwrap();
                 let mut bob = Profile::create(&ctx, &vault).await.unwrap();
 
-                bob.create_secure_channel_listener(&mut ctx, "bob_listener".into(), &vault)
-                    .await
-                    .unwrap();
+                let alice_trust_policy = IdentifierTrustPolicy::new(bob.identifier().unwrap());
+                let bob_trust_policy = IdentifierTrustPolicy::new(alice.identifier().unwrap());
+
+                bob.create_secure_channel_listener(
+                    &mut ctx,
+                    "bob_listener".into(),
+                    bob_trust_policy,
+                    &vault,
+                )
+                .await
+                .unwrap();
 
                 let alice_channel = alice
                     .create_secure_channel(
                         &mut ctx,
                         Route::new().append("bob_listener").into(),
+                        alice_trust_policy,
                         &vault,
                     )
                     .await
